==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/vpc/v20170312/models/DescribeCustomerGatewayVendorsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.vpc.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeCustomerGatewayVendorsResponse  extends AbstractModel{

    /**
    * 对端网关厂商信息对象。
    */
    @SerializedName("CustomerGatewayVendorSet")
    @Expose
    private CustomerGatewayVendor [] CustomerGatewayVendorSet;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * 获取对端网关厂商信息对象。
     * @return CustomerGatewayVendorSet 对端网关厂商信息对象。
     */
    public CustomerGatewayVendor [] getCustomerGatewayVendorSet() {
        return this.CustomerGatewayVendorSet;
    }

    /**
     * 设置对端网关厂商信息对象。
     * @param CustomerGatewayVendorSet 对端网关厂商信息对象。
     */
    public void setCustomerGatewayVendorSet(CustomerGatewayVendor [] CustomerGatewayVendorSet) {
        this.CustomerGatewayVendorSet = CustomerGatewayVendorSet;
    }

    /**
     * 获取唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * 设置唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "CustomerGatewayVendorSet.", this.CustomerGatewayVendorSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.209-sources.jar: com/tencentcloudapi/vpc/v20170312/models/DescribeCustomerGatewayVendorsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.vpc.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeCustomerGatewayVendorsResponse extends AbstractModel{

    /**
    * 对端网关厂商信息对象。
    */
    @SerializedName("CustomerGatewayVendorSet")
    @Expose
    private CustomerGatewayVendor [] CustomerGatewayVendorSet;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 对端网关厂商信息对象。 
     * @return CustomerGatewayVendorSet 对端网关厂商信息对象。
     */
    public CustomerGatewayVendor [] getCustomerGatewayVendorSet() {
        return this.CustomerGatewayVendorSet;
    }

    /**
     * Set 对端网关厂商信息对象。
     * @param CustomerGatewayVendorSet 对端网关厂商信息对象。
     */
    public void setCustomerGatewayVendorSet(CustomerGatewayVendor [] CustomerGatewayVendorSet) {
        this.CustomerGatewayVendorSet = CustomerGatewayVendorSet;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "CustomerGatewayVendorSet.", this.CustomerGatewayVendorSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
